// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: Custom.proto
// Protobuf C++ Version: 6.33.5

#ifndef Custom_2eproto_2epb_2eh
#define Custom_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 6033005
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/message.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/unknown_field_set.h"
#include "Map.pb.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_Custom_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_Custom_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_Custom_2eproto;
}  // extern "C"
namespace mojo {
namespace spec {
class CustomOp;
struct CustomOpDefaultTypeInternal;
extern CustomOpDefaultTypeInternal _CustomOp_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull CustomOp_class_data_;
class CustomParam;
struct CustomParamDefaultTypeInternal;
extern CustomParamDefaultTypeInternal _CustomParam_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull CustomParam_class_data_;
class DateTimeParam;
struct DateTimeParamDefaultTypeInternal;
extern DateTimeParamDefaultTypeInternal _DateTimeParam_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull DateTimeParam_class_data_;
}  // namespace spec
}  // namespace mojo
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google

namespace mojo {
namespace spec {

// ===================================================================


// -------------------------------------------------------------------

class DateTimeParam final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:mojo.spec.DateTimeParam) */ {
 public:
  inline DateTimeParam() : DateTimeParam(nullptr) {}
  ~DateTimeParam() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(DateTimeParam* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(DateTimeParam));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR DateTimeParam(::google::protobuf::internal::ConstantInitialized);

  inline DateTimeParam(const DateTimeParam& from) : DateTimeParam(nullptr, from) {}
  inline DateTimeParam(DateTimeParam&& from) noexcept
      : DateTimeParam(nullptr, ::std::move(from)) {}
  inline DateTimeParam& operator=(const DateTimeParam& from) {
    CopyFrom(from);
    return *this;
  }
  inline DateTimeParam& operator=(DateTimeParam&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const DateTimeParam& default_instance() {
    return *reinterpret_cast<const DateTimeParam*>(
        &_DateTimeParam_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 2;
  friend void swap(DateTimeParam& a, DateTimeParam& b) { a.Swap(&b); }
  inline void Swap(DateTimeParam* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(DateTimeParam* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  DateTimeParam* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<DateTimeParam>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const DateTimeParam& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const DateTimeParam& from) { DateTimeParam::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(DateTimeParam* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.DateTimeParam"; }

  explicit DateTimeParam(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  DateTimeParam(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const DateTimeParam& from);
  DateTimeParam(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, DateTimeParam&& from) noexcept
      : DateTimeParam(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kSecondsFieldNumber = 1,
    kNanosFieldNumber = 2,
  };
  // int64 seconds = 1;
  void clear_seconds() ;
  ::int64_t seconds() const;
  void set_seconds(::int64_t value);

  private:
  ::int64_t _internal_seconds() const;
  void _internal_set_seconds(::int64_t value);

  public:
  // uint64 nanos = 2;
  void clear_nanos() ;
  ::uint64_t nanos() const;
  void set_nanos(::uint64_t value);

  private:
  ::uint64_t _internal_nanos() const;
  void _internal_set_nanos(::uint64_t value);

  public:
  // @@protoc_insertion_point(class_scope:mojo.spec.DateTimeParam)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<1, 2,
                                   0, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const DateTimeParam& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::int64_t seconds_;
    ::uint64_t nanos_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_Custom_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull DateTimeParam_class_data_;
// -------------------------------------------------------------------

class CustomParam final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:mojo.spec.CustomParam) */ {
 public:
  inline CustomParam() : CustomParam(nullptr) {}
  ~CustomParam() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(CustomParam* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(CustomParam));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR CustomParam(::google::protobuf::internal::ConstantInitialized);

  inline CustomParam(const CustomParam& from) : CustomParam(nullptr, from) {}
  inline CustomParam(CustomParam&& from) noexcept
      : CustomParam(nullptr, ::std::move(from)) {}
  inline CustomParam& operator=(const CustomParam& from) {
    CopyFrom(from);
    return *this;
  }
  inline CustomParam& operator=(CustomParam&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const CustomParam& default_instance() {
    return *reinterpret_cast<const CustomParam*>(
        &_CustomParam_default_instance_);
  }
  enum ParamTypeCase {
    kBoolParam = 2,
    kInt32Param = 3,
    kInt64Param = 4,
    kFloat32Param = 5,
    kFloat64Param = 6,
    kStringParam = 7,
    kDatetimeParam = 8,
    kBinaryParam = 13,
    PARAM_TYPE_NOT_SET = 0,
  };
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(CustomParam& a, CustomParam& b) { a.Swap(&b); }
  inline void Swap(CustomParam* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(CustomParam* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  CustomParam* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<CustomParam>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const CustomParam& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const CustomParam& from) { CustomParam::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(CustomParam* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.CustomParam"; }

  explicit CustomParam(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  CustomParam(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const CustomParam& from);
  CustomParam(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, CustomParam&& from) noexcept
      : CustomParam(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kNameFieldNumber = 1,
    kBoolParamFieldNumber = 2,
    kInt32ParamFieldNumber = 3,
    kInt64ParamFieldNumber = 4,
    kFloat32ParamFieldNumber = 5,
    kFloat64ParamFieldNumber = 6,
    kStringParamFieldNumber = 7,
    kDatetimeParamFieldNumber = 8,
    kBinaryParamFieldNumber = 13,
  };
  // string name = 1;
  void clear_name() ;
  const ::std::string& name() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_name(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_name();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_name();
  void set_allocated_name(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_name() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_name(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_name();

  public:
  // bool bool_param = 2;
  bool has_bool_param() const;
  void clear_bool_param() ;
  bool bool_param() const;
  void set_bool_param(bool value);

  private:
  bool _internal_bool_param() const;
  void _internal_set_bool_param(bool value);

  public:
  // int32 int32_param = 3;
  bool has_int32_param() const;
  void clear_int32_param() ;
  ::int32_t int32_param() const;
  void set_int32_param(::int32_t value);

  private:
  ::int32_t _internal_int32_param() const;
  void _internal_set_int32_param(::int32_t value);

  public:
  // int64 int64_param = 4;
  bool has_int64_param() const;
  void clear_int64_param() ;
  ::int64_t int64_param() const;
  void set_int64_param(::int64_t value);

  private:
  ::int64_t _internal_int64_param() const;
  void _internal_set_int64_param(::int64_t value);

  public:
  // float float32_param = 5;
  bool has_float32_param() const;
  void clear_float32_param() ;
  float float32_param() const;
  void set_float32_param(float value);

  private:
  float _internal_float32_param() const;
  void _internal_set_float32_param(float value);

  public:
  // double float64_param = 6;
  bool has_float64_param() const;
  void clear_float64_param() ;
  double float64_param() const;
  void set_float64_param(double value);

  private:
  double _internal_float64_param() const;
  void _internal_set_float64_param(double value);

  public:
  // string string_param = 7;
  bool has_string_param() const;
  void clear_string_param() ;
  const ::std::string& string_param() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_string_param(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_string_param();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_string_param();
  void set_allocated_string_param(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_string_param() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_string_param(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_string_param();

  public:
  // .mojo.spec.DateTimeParam datetime_param = 8;
  bool has_datetime_param() const;
  private:
  bool _internal_has_datetime_param() const;

  public:
  void clear_datetime_param() ;
  const ::mojo::spec::DateTimeParam& datetime_param() const;
  [[nodiscard]] ::mojo::spec::DateTimeParam* PROTOBUF_NULLABLE release_datetime_param();
  ::mojo::spec::DateTimeParam* PROTOBUF_NONNULL mutable_datetime_param();
  void set_allocated_datetime_param(::mojo::spec::DateTimeParam* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_datetime_param(::mojo::spec::DateTimeParam* PROTOBUF_NULLABLE value);
  ::mojo::spec::DateTimeParam* PROTOBUF_NULLABLE unsafe_arena_release_datetime_param();

  private:
  const ::mojo::spec::DateTimeParam& _internal_datetime_param() const;
  ::mojo::spec::DateTimeParam* PROTOBUF_NONNULL _internal_mutable_datetime_param();

  public:
  // .mojo.spec.ExternalData binary_param = 13;
  bool has_binary_param() const;
  private:
  bool _internal_has_binary_param() const;

  public:
  void clear_binary_param() ;
  const ::mojo::spec::ExternalData& binary_param() const;
  [[nodiscard]] ::mojo::spec::ExternalData* PROTOBUF_NULLABLE release_binary_param();
  ::mojo::spec::ExternalData* PROTOBUF_NONNULL mutable_binary_param();
  void set_allocated_binary_param(::mojo::spec::ExternalData* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_binary_param(::mojo::spec::ExternalData* PROTOBUF_NULLABLE value);
  ::mojo::spec::ExternalData* PROTOBUF_NULLABLE unsafe_arena_release_binary_param();

  private:
  const ::mojo::spec::ExternalData& _internal_binary_param() const;
  ::mojo::spec::ExternalData* PROTOBUF_NONNULL _internal_mutable_binary_param();

  public:
  void clear_param_type();
  ParamTypeCase param_type_case() const;
  // @@protoc_insertion_point(class_scope:mojo.spec.CustomParam)
 private:
  class _Internal;
  void set_has_bool_param();
  void set_has_int32_param();
  void set_has_int64_param();
  void set_has_float32_param();
  void set_has_float64_param();
  void set_has_string_param();
  void set_has_datetime_param();
  void set_has_binary_param();
  inline bool has_param_type() const;
  inline void clear_has_param_type();
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<0, 9,
                                   2, 54,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const CustomParam& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr name_;
    union ParamTypeUnion {
      constexpr ParamTypeUnion() : _constinit_{} {}
      ::google::protobuf::internal::ConstantInitialized _constinit_;
      bool bool_param_;
      ::int32_t int32_param_;
      ::int64_t int64_param_;
      float float32_param_;
      double float64_param_;
      ::google::protobuf::internal::ArenaStringPtr string_param_;
      ::mojo::spec::DateTimeParam* PROTOBUF_NULLABLE datetime_param_;
      ::mojo::spec::ExternalData* PROTOBUF_NULLABLE binary_param_;
    } param_type_;
    ::uint32_t _oneof_case_[1];
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_Custom_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull CustomParam_class_data_;
// -------------------------------------------------------------------

class CustomOp final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:mojo.spec.CustomOp) */ {
 public:
  inline CustomOp() : CustomOp(nullptr) {}
  ~CustomOp() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(CustomOp* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(CustomOp));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR CustomOp(::google::protobuf::internal::ConstantInitialized);

  inline CustomOp(const CustomOp& from) : CustomOp(nullptr, from) {}
  inline CustomOp(CustomOp&& from) noexcept
      : CustomOp(nullptr, ::std::move(from)) {}
  inline CustomOp& operator=(const CustomOp& from) {
    CopyFrom(from);
    return *this;
  }
  inline CustomOp& operator=(CustomOp&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const CustomOp& default_instance() {
    return *reinterpret_cast<const CustomOp*>(
        &_CustomOp_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(CustomOp& a, CustomOp& b) { a.Swap(&b); }
  inline void Swap(CustomOp* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(CustomOp* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  CustomOp* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<CustomOp>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const CustomOp& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const CustomOp& from) { CustomOp::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(CustomOp* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.CustomOp"; }

  explicit CustomOp(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  CustomOp(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const CustomOp& from);
  CustomOp(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, CustomOp&& from) noexcept
      : CustomOp(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kParamsFieldNumber = 3,
    kTransformerNameFieldNumber = 1,
  };
  // repeated .mojo.spec.CustomParam params = 3;
  int params_size() const;
  private:
  int _internal_params_size() const;

  public:
  void clear_params() ;
  ::mojo::spec::CustomParam* PROTOBUF_NONNULL mutable_params(int index);
  ::google::protobuf::RepeatedPtrField<::mojo::spec::CustomParam>* PROTOBUF_NONNULL mutable_params();

  private:
  const ::google::protobuf::RepeatedPtrField<::mojo::spec::CustomParam>& _internal_params() const;
  ::google::protobuf::RepeatedPtrField<::mojo::spec::CustomParam>* PROTOBUF_NONNULL _internal_mutable_params();
  public:
  const ::mojo::spec::CustomParam& params(int index) const;
  ::mojo::spec::CustomParam* PROTOBUF_NONNULL add_params();
  const ::google::protobuf::RepeatedPtrField<::mojo::spec::CustomParam>& params() const;
  // string transformer_name = 1;
  void clear_transformer_name() ;
  const ::std::string& transformer_name() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_transformer_name(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_transformer_name();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_transformer_name();
  void set_allocated_transformer_name(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_transformer_name() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_transformer_name(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_transformer_name();

  public:
  // @@protoc_insertion_point(class_scope:mojo.spec.CustomOp)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<2, 2,
                                   1, 43,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const CustomOp& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::mojo::spec::CustomParam > params_;
    ::google::protobuf::internal::ArenaStringPtr transformer_name_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_Custom_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull CustomOp_class_data_;

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// CustomOp

// string transformer_name = 1;
inline void CustomOp::clear_transformer_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.transformer_name_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
inline const ::std::string& CustomOp::transformer_name() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.CustomOp.transformer_name)
  return _internal_transformer_name();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void CustomOp::set_transformer_name(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.transformer_name_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:mojo.spec.CustomOp.transformer_name)
}
inline ::std::string* PROTOBUF_NONNULL CustomOp::mutable_transformer_name()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_transformer_name();
  // @@protoc_insertion_point(field_mutable:mojo.spec.CustomOp.transformer_name)
  return _s;
}
inline const ::std::string& CustomOp::_internal_transformer_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.transformer_name_.Get();
}
inline void CustomOp::_internal_set_transformer_name(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.transformer_name_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL CustomOp::_internal_mutable_transformer_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.transformer_name_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE CustomOp::release_transformer_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:mojo.spec.CustomOp.transformer_name)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.transformer_name_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.transformer_name_.Set("", GetArena());
  }
  return released;
}
inline void CustomOp::set_allocated_transformer_name(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.transformer_name_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.transformer_name_.IsDefault()) {
    _impl_.transformer_name_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:mojo.spec.CustomOp.transformer_name)
}

// repeated .mojo.spec.CustomParam params = 3;
inline int CustomOp::_internal_params_size() const {
  return _internal_params().size();
}
inline int CustomOp::params_size() const {
  return _internal_params_size();
}
inline void CustomOp::clear_params() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.params_.Clear();
  ClearHasBitForRepeated(_impl_._has_bits_[0],
                  0x00000001U);
}
inline ::mojo::spec::CustomParam* PROTOBUF_NONNULL CustomOp::mutable_params(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:mojo.spec.CustomOp.params)
  return _internal_mutable_params()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::mojo::spec::CustomParam>* PROTOBUF_NONNULL CustomOp::mutable_params()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:mojo.spec.CustomOp.params)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_params();
}
inline const ::mojo::spec::CustomParam& CustomOp::params(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.CustomOp.params)
  return _internal_params().Get(index);
}
inline ::mojo::spec::CustomParam* PROTOBUF_NONNULL CustomOp::add_params()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::mojo::spec::CustomParam* _add =
      _internal_mutable_params()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:mojo.spec.CustomOp.params)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::mojo::spec::CustomParam>& CustomOp::params() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:mojo.spec.CustomOp.params)
  return _internal_params();
}
inline const ::google::protobuf::RepeatedPtrField<::mojo::spec::CustomParam>&
CustomOp::_internal_params() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.params_;
}
inline ::google::protobuf::RepeatedPtrField<::mojo::spec::CustomParam>* PROTOBUF_NONNULL
CustomOp::_internal_mutable_params() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.params_;
}

// -------------------------------------------------------------------

// CustomParam

// string name = 1;
inline void CustomParam::clear_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
inline const ::std::string& CustomParam::name() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.CustomParam.name)
  return _internal_name();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void CustomParam::set_name(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.name_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:mojo.spec.CustomParam.name)
}
inline ::std::string* PROTOBUF_NONNULL CustomParam::mutable_name()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:mojo.spec.CustomParam.name)
  return _s;
}
inline const ::std::string& CustomParam::_internal_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.name_.Get();
}
inline void CustomParam::_internal_set_name(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL CustomParam::_internal_mutable_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.name_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE CustomParam::release_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:mojo.spec.CustomParam.name)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.name_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.name_.Set("", GetArena());
  }
  return released;
}
inline void CustomParam::set_allocated_name(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.name_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.name_.IsDefault()) {
    _impl_.name_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:mojo.spec.CustomParam.name)
}

// bool bool_param = 2;
inline bool CustomParam::has_bool_param() const {
  return param_type_case() == kBoolParam;
}
inline void CustomParam::set_has_bool_param() {
  _impl_._oneof_case_[0] = kBoolParam;
}
inline void CustomParam::clear_bool_param() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (param_type_case() == kBoolParam) {
    _impl_.param_type_.bool_param_ = false;
    clear_has_param_type();
  }
}
inline bool CustomParam::bool_param() const {
  // @@protoc_insertion_point(field_get:mojo.spec.CustomParam.bool_param)
  return _internal_bool_param();
}
inline void CustomParam::set_bool_param(bool value) {
  if (param_type_case() != kBoolParam) {
    clear_param_type();
    set_has_bool_param();
  }
  _impl_.param_type_.bool_param_ = value;
  // @@protoc_insertion_point(field_set:mojo.spec.CustomParam.bool_param)
}
inline bool CustomParam::_internal_bool_param() const {
  if (param_type_case() == kBoolParam) {
    return _impl_.param_type_.bool_param_;
  }
  return false;
}

// int32 int32_param = 3;
inline bool CustomParam::has_int32_param() const {
  return param_type_case() == kInt32Param;
}
inline void CustomParam::set_has_int32_param() {
  _impl_._oneof_case_[0] = kInt32Param;
}
inline void CustomParam::clear_int32_param() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (param_type_case() == kInt32Param) {
    _impl_.param_type_.int32_param_ = 0;
    clear_has_param_type();
  }
}
inline ::int32_t CustomParam::int32_param() const {
  // @@protoc_insertion_point(field_get:mojo.spec.CustomParam.int32_param)
  return _internal_int32_param();
}
inline void CustomParam::set_int32_param(::int32_t value) {
  if (param_type_case() != kInt32Param) {
    clear_param_type();
    set_has_int32_param();
  }
  _impl_.param_type_.int32_param_ = value;
  // @@protoc_insertion_point(field_set:mojo.spec.CustomParam.int32_param)
}
inline ::int32_t CustomParam::_internal_int32_param() const {
  if (param_type_case() == kInt32Param) {
    return _impl_.param_type_.int32_param_;
  }
  return 0;
}

// int64 int64_param = 4;
inline bool CustomParam::has_int64_param() const {
  return param_type_case() == kInt64Param;
}
inline void CustomParam::set_has_int64_param() {
  _impl_._oneof_case_[0] = kInt64Param;
}
inline void CustomParam::clear_int64_param() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (param_type_case() == kInt64Param) {
    _impl_.param_type_.int64_param_ = ::int64_t{0};
    clear_has_param_type();
  }
}
inline ::int64_t CustomParam::int64_param() const {
  // @@protoc_insertion_point(field_get:mojo.spec.CustomParam.int64_param)
  return _internal_int64_param();
}
inline void CustomParam::set_int64_param(::int64_t value) {
  if (param_type_case() != kInt64Param) {
    clear_param_type();
    set_has_int64_param();
  }
  _impl_.param_type_.int64_param_ = value;
  // @@protoc_insertion_point(field_set:mojo.spec.CustomParam.int64_param)
}
inline ::int64_t CustomParam::_internal_int64_param() const {
  if (param_type_case() == kInt64Param) {
    return _impl_.param_type_.int64_param_;
  }
  return ::int64_t{0};
}

// float float32_param = 5;
inline bool CustomParam::has_float32_param() const {
  return param_type_case() == kFloat32Param;
}
inline void CustomParam::set_has_float32_param() {
  _impl_._oneof_case_[0] = kFloat32Param;
}
inline void CustomParam::clear_float32_param() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (param_type_case() == kFloat32Param) {
    _impl_.param_type_.float32_param_ = 0;
    clear_has_param_type();
  }
}
inline float CustomParam::float32_param() const {
  // @@protoc_insertion_point(field_get:mojo.spec.CustomParam.float32_param)
  return _internal_float32_param();
}
inline void CustomParam::set_float32_param(float value) {
  if (param_type_case() != kFloat32Param) {
    clear_param_type();
    set_has_float32_param();
  }
  _impl_.param_type_.float32_param_ = value;
  // @@protoc_insertion_point(field_set:mojo.spec.CustomParam.float32_param)
}
inline float CustomParam::_internal_float32_param() const {
  if (param_type_case() == kFloat32Param) {
    return _impl_.param_type_.float32_param_;
  }
  return 0;
}

// double float64_param = 6;
inline bool CustomParam::has_float64_param() const {
  return param_type_case() == kFloat64Param;
}
inline void CustomParam::set_has_float64_param() {
  _impl_._oneof_case_[0] = kFloat64Param;
}
inline void CustomParam::clear_float64_param() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (param_type_case() == kFloat64Param) {
    _impl_.param_type_.float64_param_ = 0;
    clear_has_param_type();
  }
}
inline double CustomParam::float64_param() const {
  // @@protoc_insertion_point(field_get:mojo.spec.CustomParam.float64_param)
  return _internal_float64_param();
}
inline void CustomParam::set_float64_param(double value) {
  if (param_type_case() != kFloat64Param) {
    clear_param_type();
    set_has_float64_param();
  }
  _impl_.param_type_.float64_param_ = value;
  // @@protoc_insertion_point(field_set:mojo.spec.CustomParam.float64_param)
}
inline double CustomParam::_internal_float64_param() const {
  if (param_type_case() == kFloat64Param) {
    return _impl_.param_type_.float64_param_;
  }
  return 0;
}

// string string_param = 7;
inline bool CustomParam::has_string_param() const {
  return param_type_case() == kStringParam;
}
inline void CustomParam::set_has_string_param() {
  _impl_._oneof_case_[0] = kStringParam;
}
inline void CustomParam::clear_string_param() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (param_type_case() == kStringParam) {
    _impl_.param_type_.string_param_.Destroy();
    clear_has_param_type();
  }
}
inline const ::std::string& CustomParam::string_param() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.CustomParam.string_param)
  return _internal_string_param();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void CustomParam::set_string_param(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (param_type_case() != kStringParam) {
    clear_param_type();

    set_has_string_param();
    _impl_.param_type_.string_param_.InitDefault();
  }
  _impl_.param_type_.string_param_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:mojo.spec.CustomParam.string_param)
}
inline ::std::string* PROTOBUF_NONNULL CustomParam::mutable_string_param()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  if (param_type_case() != kStringParam) {
    clear_param_type();

    set_has_string_param();
    _impl_.param_type_.string_param_.InitDefault();
  }
  ::std::string* _s = _internal_mutable_string_param();
  // @@protoc_insertion_point(field_mutable:mojo.spec.CustomParam.string_param)
  return _s;
}
inline const ::std::string& CustomParam::_internal_string_param() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  if (param_type_case() != kStringParam) {
    return ::google::protobuf::internal::GetEmptyStringAlreadyInited();
  }
  return _impl_.param_type_.string_param_.Get();
}
inline void CustomParam::_internal_set_string_param(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.param_type_.string_param_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL CustomParam::_internal_mutable_string_param() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.param_type_.string_param_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE CustomParam::release_string_param() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:mojo.spec.CustomParam.string_param)
  if (param_type_case() != kStringParam) {
    return nullptr;
  }
  clear_has_param_type();
  return _impl_.param_type_.string_param_.Release();
}
inline void CustomParam::set_allocated_string_param(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (has_param_type()) {
    clear_param_type();
  }
  if (value != nullptr) {
    set_has_string_param();
    _impl_.param_type_.string_param_.InitAllocated(value, GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:mojo.spec.CustomParam.string_param)
}

// .mojo.spec.DateTimeParam datetime_param = 8;
inline bool CustomParam::has_datetime_param() const {
  return param_type_case() == kDatetimeParam;
}
inline bool CustomParam::_internal_has_datetime_param() const {
  return param_type_case() == kDatetimeParam;
}
inline void CustomParam::set_has_datetime_param() {
  _impl_._oneof_case_[0] = kDatetimeParam;
}
inline void CustomParam::clear_datetime_param() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (param_type_case() == kDatetimeParam) {
    if (GetArena() == nullptr) {
      delete _impl_.param_type_.datetime_param_;
    } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
      ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.param_type_.datetime_param_);
    }
    clear_has_param_type();
  }
}
inline ::mojo::spec::DateTimeParam* PROTOBUF_NULLABLE CustomParam::release_datetime_param() {
  // @@protoc_insertion_point(field_release:mojo.spec.CustomParam.datetime_param)
  if (param_type_case() == kDatetimeParam) {
    clear_has_param_type();
    auto* temp = _impl_.param_type_.datetime_param_;
    if (GetArena() != nullptr) {
      temp = ::google::protobuf::internal::DuplicateIfNonNull(temp);
    }
    _impl_.param_type_.datetime_param_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::mojo::spec::DateTimeParam& CustomParam::_internal_datetime_param() const {
  return param_type_case() == kDatetimeParam ? static_cast<const ::mojo::spec::DateTimeParam&>(*_impl_.param_type_.datetime_param_)
                     : reinterpret_cast<const ::mojo::spec::DateTimeParam&>(::mojo::spec::_DateTimeParam_default_instance_);
}
inline const ::mojo::spec::DateTimeParam& CustomParam::datetime_param() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.CustomParam.datetime_param)
  return _internal_datetime_param();
}
inline ::mojo::spec::DateTimeParam* PROTOBUF_NULLABLE CustomParam::unsafe_arena_release_datetime_param() {
  // @@protoc_insertion_point(field_unsafe_arena_release:mojo.spec.CustomParam.datetime_param)
  if (param_type_case() == kDatetimeParam) {
    clear_has_param_type();
    auto* temp = _impl_.param_type_.datetime_param_;
    _impl_.param_type_.datetime_param_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void CustomParam::unsafe_arena_set_allocated_datetime_param(
    ::mojo::spec::DateTimeParam* PROTOBUF_NULLABLE value) {
  // We rely on the oneof clear method to free the earlier contents
  // of this oneof. We can directly use the pointer we're given to
  // set the new value.
  clear_param_type();
  if (value) {
    set_has_datetime_param();
    _impl_.param_type_.datetime_param_ = value;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:mojo.spec.CustomParam.datetime_param)
}
inline ::mojo::spec::DateTimeParam* PROTOBUF_NONNULL CustomParam::_internal_mutable_datetime_param() {
  if (param_type_case() != kDatetimeParam) {
    clear_param_type();
    set_has_datetime_param();
    _impl_.param_type_.datetime_param_ = 
        ::google::protobuf::Message::DefaultConstruct<::mojo::spec::DateTimeParam>(GetArena());
  }
  return _impl_.param_type_.datetime_param_;
}
inline ::mojo::spec::DateTimeParam* PROTOBUF_NONNULL CustomParam::mutable_datetime_param()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::mojo::spec::DateTimeParam* _msg = _internal_mutable_datetime_param();
  // @@protoc_insertion_point(field_mutable:mojo.spec.CustomParam.datetime_param)
  return _msg;
}

// .mojo.spec.ExternalData binary_param = 13;
inline bool CustomParam::has_binary_param() const {
  return param_type_case() == kBinaryParam;
}
inline bool CustomParam::_internal_has_binary_param() const {
  return param_type_case() == kBinaryParam;
}
inline void CustomParam::set_has_binary_param() {
  _impl_._oneof_case_[0] = kBinaryParam;
}
inline ::mojo::spec::ExternalData* PROTOBUF_NULLABLE CustomParam::release_binary_param() {
  // @@protoc_insertion_point(field_release:mojo.spec.CustomParam.binary_param)
  if (param_type_case() == kBinaryParam) {
    clear_has_param_type();
    auto* temp = _impl_.param_type_.binary_param_;
    if (GetArena() != nullptr) {
      temp = ::google::protobuf::internal::DuplicateIfNonNull(temp);
    }
    _impl_.param_type_.binary_param_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::mojo::spec::ExternalData& CustomParam::_internal_binary_param() const {
  return param_type_case() == kBinaryParam ? static_cast<const ::mojo::spec::ExternalData&>(*_impl_.param_type_.binary_param_)
                     : reinterpret_cast<const ::mojo::spec::ExternalData&>(::mojo::spec::_ExternalData_default_instance_);
}
inline const ::mojo::spec::ExternalData& CustomParam::binary_param() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.CustomParam.binary_param)
  return _internal_binary_param();
}
inline ::mojo::spec::ExternalData* PROTOBUF_NULLABLE CustomParam::unsafe_arena_release_binary_param() {
  // @@protoc_insertion_point(field_unsafe_arena_release:mojo.spec.CustomParam.binary_param)
  if (param_type_case() == kBinaryParam) {
    clear_has_param_type();
    auto* temp = _impl_.param_type_.binary_param_;
    _impl_.param_type_.binary_param_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void CustomParam::unsafe_arena_set_allocated_binary_param(
    ::mojo::spec::ExternalData* PROTOBUF_NULLABLE value) {
  // We rely on the oneof clear method to free the earlier contents
  // of this oneof. We can directly use the pointer we're given to
  // set the new value.
  clear_param_type();
  if (value) {
    set_has_binary_param();
    _impl_.param_type_.binary_param_ = value;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:mojo.spec.CustomParam.binary_param)
}
inline ::mojo::spec::ExternalData* PROTOBUF_NONNULL CustomParam::_internal_mutable_binary_param() {
  if (param_type_case() != kBinaryParam) {
    clear_param_type();
    set_has_binary_param();
    _impl_.param_type_.binary_param_ = 
        ::google::protobuf::Message::DefaultConstruct<::mojo::spec::ExternalData>(GetArena());
  }
  return _impl_.param_type_.binary_param_;
}
inline ::mojo::spec::ExternalData* PROTOBUF_NONNULL CustomParam::mutable_binary_param()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::mojo::spec::ExternalData* _msg = _internal_mutable_binary_param();
  // @@protoc_insertion_point(field_mutable:mojo.spec.CustomParam.binary_param)
  return _msg;
}

inline bool CustomParam::has_param_type() const {
  return param_type_case() != PARAM_TYPE_NOT_SET;
}
inline void CustomParam::clear_has_param_type() {
  _impl_._oneof_case_[0] = PARAM_TYPE_NOT_SET;
}
inline CustomParam::ParamTypeCase CustomParam::param_type_case() const {
  return CustomParam::ParamTypeCase(_impl_._oneof_case_[0]);
}
// -------------------------------------------------------------------

// DateTimeParam

// int64 seconds = 1;
inline void DateTimeParam::clear_seconds() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.seconds_ = ::int64_t{0};
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
inline ::int64_t DateTimeParam::seconds() const {
  // @@protoc_insertion_point(field_get:mojo.spec.DateTimeParam.seconds)
  return _internal_seconds();
}
inline void DateTimeParam::set_seconds(::int64_t value) {
  _internal_set_seconds(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_set:mojo.spec.DateTimeParam.seconds)
}
inline ::int64_t DateTimeParam::_internal_seconds() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.seconds_;
}
inline void DateTimeParam::_internal_set_seconds(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.seconds_ = value;
}

// uint64 nanos = 2;
inline void DateTimeParam::clear_nanos() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.nanos_ = ::uint64_t{0u};
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
inline ::uint64_t DateTimeParam::nanos() const {
  // @@protoc_insertion_point(field_get:mojo.spec.DateTimeParam.nanos)
  return _internal_nanos();
}
inline void DateTimeParam::set_nanos(::uint64_t value) {
  _internal_set_nanos(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_set:mojo.spec.DateTimeParam.nanos)
}
inline ::uint64_t DateTimeParam::_internal_nanos() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.nanos_;
}
inline void DateTimeParam::_internal_set_nanos(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.nanos_ = value;
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace spec
}  // namespace mojo


// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"

#endif  // Custom_2eproto_2epb_2eh
