// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: NA.proto
// Protobuf C++ Version: 6.33.5

#ifndef NA_2eproto_2epb_2eh
#define NA_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 6033005
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_bases.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/message.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/generated_enum_reflection.h"
#include "google/protobuf/unknown_field_set.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_NA_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_NA_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_NA_2eproto;
}  // extern "C"
namespace mojo {
namespace spec {
enum ImputeType : int;
extern const uint32_t ImputeType_internal_data_[];
class FillNaOp;
struct FillNaOpDefaultTypeInternal;
extern FillNaOpDefaultTypeInternal _FillNaOp_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull FillNaOp_class_data_;
class ImputeNaOp;
struct ImputeNaOpDefaultTypeInternal;
extern ImputeNaOpDefaultTypeInternal _ImputeNaOp_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull ImputeNaOp_class_data_;
class IsNaOp;
struct IsNaOpDefaultTypeInternal;
extern IsNaOpDefaultTypeInternal _IsNaOp_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull IsNaOp_class_data_;
}  // namespace spec
}  // namespace mojo
namespace google {
namespace protobuf {
template <>
internal::EnumTraitsT<::mojo::spec::ImputeType_internal_data_>
    internal::EnumTraitsImpl::value<::mojo::spec::ImputeType>;
}  // namespace protobuf
}  // namespace google

namespace mojo {
namespace spec {
enum ImputeType : int {
  UNKNOWN_IMPUTE_TYPE = 0,
  MEAN = 1,
  ImputeType_INT_MIN_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::min(),
  ImputeType_INT_MAX_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::max(),
};

extern const uint32_t ImputeType_internal_data_[];
inline constexpr ImputeType ImputeType_MIN =
    static_cast<ImputeType>(0);
inline constexpr ImputeType ImputeType_MAX =
    static_cast<ImputeType>(1);
inline bool ImputeType_IsValid(int value) {
  return 0 <= value && value <= 1;
}
inline constexpr int ImputeType_ARRAYSIZE = 1 + 1;
const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL ImputeType_descriptor();
template <typename T>
const ::std::string& ImputeType_Name(T value) {
  static_assert(::std::is_same<T, ImputeType>::value ||
                    ::std::is_integral<T>::value,
                "Incorrect type passed to ImputeType_Name().");
  return ImputeType_Name(static_cast<ImputeType>(value));
}
template <>
inline const ::std::string& ImputeType_Name(ImputeType value) {
  return ::google::protobuf::internal::NameOfDenseEnum<ImputeType_descriptor, 0, 1>(
      static_cast<int>(value));
}
inline bool ImputeType_Parse(
    ::absl::string_view name, ImputeType* PROTOBUF_NONNULL value) {
  return ::google::protobuf::internal::ParseNamedEnum<ImputeType>(ImputeType_descriptor(), name,
                                           value);
}

// ===================================================================


// -------------------------------------------------------------------

class IsNaOp final : public ::google::protobuf::internal::ZeroFieldsBase
/* @@protoc_insertion_point(class_definition:mojo.spec.IsNaOp) */ {
 public:
  inline IsNaOp() : IsNaOp(nullptr) {}

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(IsNaOp* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(IsNaOp));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR IsNaOp(::google::protobuf::internal::ConstantInitialized);

  inline IsNaOp(const IsNaOp& from) : IsNaOp(nullptr, from) {}
  inline IsNaOp(IsNaOp&& from) noexcept
      : IsNaOp(nullptr, ::std::move(from)) {}
  inline IsNaOp& operator=(const IsNaOp& from) {
    CopyFrom(from);
    return *this;
  }
  inline IsNaOp& operator=(IsNaOp&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const IsNaOp& default_instance() {
    return *reinterpret_cast<const IsNaOp*>(
        &_IsNaOp_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(IsNaOp& a, IsNaOp& b) { a.Swap(&b); }
  inline void Swap(IsNaOp* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(IsNaOp* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  IsNaOp* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::internal::ZeroFieldsBase::DefaultConstruct<IsNaOp>(arena);
  }
  using ::google::protobuf::internal::ZeroFieldsBase::CopyFrom;
  inline void CopyFrom(const IsNaOp& from) {
    ::google::protobuf::internal::ZeroFieldsBase::CopyImpl(*this, from);
  }
  using ::google::protobuf::internal::ZeroFieldsBase::MergeFrom;
  void MergeFrom(const IsNaOp& from) {
    ::google::protobuf::internal::ZeroFieldsBase::MergeImpl(*this, from);
  }

  public:
  bool IsInitialized() const {
    return true;
  }
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.IsNaOp"; }

  explicit IsNaOp(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  IsNaOp(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const IsNaOp& from);
  IsNaOp(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, IsNaOp&& from) noexcept
      : IsNaOp(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  // @@protoc_insertion_point(class_scope:mojo.spec.IsNaOp)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<0, 0,
                                   0, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  friend struct ::TableStruct_NA_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull IsNaOp_class_data_;
// -------------------------------------------------------------------

class ImputeNaOp final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:mojo.spec.ImputeNaOp) */ {
 public:
  inline ImputeNaOp() : ImputeNaOp(nullptr) {}
  ~ImputeNaOp() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(ImputeNaOp* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(ImputeNaOp));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR ImputeNaOp(::google::protobuf::internal::ConstantInitialized);

  inline ImputeNaOp(const ImputeNaOp& from) : ImputeNaOp(nullptr, from) {}
  inline ImputeNaOp(ImputeNaOp&& from) noexcept
      : ImputeNaOp(nullptr, ::std::move(from)) {}
  inline ImputeNaOp& operator=(const ImputeNaOp& from) {
    CopyFrom(from);
    return *this;
  }
  inline ImputeNaOp& operator=(ImputeNaOp&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const ImputeNaOp& default_instance() {
    return *reinterpret_cast<const ImputeNaOp*>(
        &_ImputeNaOp_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 2;
  friend void swap(ImputeNaOp& a, ImputeNaOp& b) { a.Swap(&b); }
  inline void Swap(ImputeNaOp* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ImputeNaOp* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  ImputeNaOp* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<ImputeNaOp>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const ImputeNaOp& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const ImputeNaOp& from) { ImputeNaOp::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(ImputeNaOp* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.ImputeNaOp"; }

  explicit ImputeNaOp(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  ImputeNaOp(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const ImputeNaOp& from);
  ImputeNaOp(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, ImputeNaOp&& from) noexcept
      : ImputeNaOp(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kTypeFieldNumber = 1,
  };
  // .mojo.spec.ImputeType type = 1;
  void clear_type() ;
  ::mojo::spec::ImputeType type() const;
  void set_type(::mojo::spec::ImputeType value);

  private:
  ::mojo::spec::ImputeType _internal_type() const;
  void _internal_set_type(::mojo::spec::ImputeType value);

  public:
  // @@protoc_insertion_point(class_scope:mojo.spec.ImputeNaOp)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<0, 1,
                                   0, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const ImputeNaOp& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    int type_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_NA_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull ImputeNaOp_class_data_;
// -------------------------------------------------------------------

class FillNaOp final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:mojo.spec.FillNaOp) */ {
 public:
  inline FillNaOp() : FillNaOp(nullptr) {}
  ~FillNaOp() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(FillNaOp* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(FillNaOp));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR FillNaOp(::google::protobuf::internal::ConstantInitialized);

  inline FillNaOp(const FillNaOp& from) : FillNaOp(nullptr, from) {}
  inline FillNaOp(FillNaOp&& from) noexcept
      : FillNaOp(nullptr, ::std::move(from)) {}
  inline FillNaOp& operator=(const FillNaOp& from) {
    CopyFrom(from);
    return *this;
  }
  inline FillNaOp& operator=(FillNaOp&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const FillNaOp& default_instance() {
    return *reinterpret_cast<const FillNaOp*>(
        &_FillNaOp_default_instance_);
  }
  enum ReplacementCase {
    kInt32Replacement = 1,
    kInt64Replacement = 2,
    kFloat32Replacement = 3,
    kFloat64Replacement = 4,
    kStringReplacement = 5,
    kBoolReplacement = 6,
    REPLACEMENT_NOT_SET = 0,
  };
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(FillNaOp& a, FillNaOp& b) { a.Swap(&b); }
  inline void Swap(FillNaOp* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(FillNaOp* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  FillNaOp* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<FillNaOp>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const FillNaOp& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const FillNaOp& from) { FillNaOp::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(FillNaOp* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.FillNaOp"; }

  explicit FillNaOp(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  FillNaOp(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const FillNaOp& from);
  FillNaOp(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, FillNaOp&& from) noexcept
      : FillNaOp(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kInt32ReplacementFieldNumber = 1,
    kInt64ReplacementFieldNumber = 2,
    kFloat32ReplacementFieldNumber = 3,
    kFloat64ReplacementFieldNumber = 4,
    kStringReplacementFieldNumber = 5,
    kBoolReplacementFieldNumber = 6,
  };
  // int32 int32_replacement = 1;
  bool has_int32_replacement() const;
  void clear_int32_replacement() ;
  ::int32_t int32_replacement() const;
  void set_int32_replacement(::int32_t value);

  private:
  ::int32_t _internal_int32_replacement() const;
  void _internal_set_int32_replacement(::int32_t value);

  public:
  // int64 int64_replacement = 2;
  bool has_int64_replacement() const;
  void clear_int64_replacement() ;
  ::int64_t int64_replacement() const;
  void set_int64_replacement(::int64_t value);

  private:
  ::int64_t _internal_int64_replacement() const;
  void _internal_set_int64_replacement(::int64_t value);

  public:
  // float float32_replacement = 3;
  bool has_float32_replacement() const;
  void clear_float32_replacement() ;
  float float32_replacement() const;
  void set_float32_replacement(float value);

  private:
  float _internal_float32_replacement() const;
  void _internal_set_float32_replacement(float value);

  public:
  // double float64_replacement = 4;
  bool has_float64_replacement() const;
  void clear_float64_replacement() ;
  double float64_replacement() const;
  void set_float64_replacement(double value);

  private:
  double _internal_float64_replacement() const;
  void _internal_set_float64_replacement(double value);

  public:
  // string string_replacement = 5;
  bool has_string_replacement() const;
  void clear_string_replacement() ;
  const ::std::string& string_replacement() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_string_replacement(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_string_replacement();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_string_replacement();
  void set_allocated_string_replacement(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_string_replacement() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_string_replacement(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_string_replacement();

  public:
  // bool bool_replacement = 6;
  bool has_bool_replacement() const;
  void clear_bool_replacement() ;
  bool bool_replacement() const;
  void set_bool_replacement(bool value);

  private:
  bool _internal_bool_replacement() const;
  void _internal_set_bool_replacement(bool value);

  public:
  void clear_Replacement();
  ReplacementCase Replacement_case() const;
  // @@protoc_insertion_point(class_scope:mojo.spec.FillNaOp)
 private:
  class _Internal;
  void set_has_int32_replacement();
  void set_has_int64_replacement();
  void set_has_float32_replacement();
  void set_has_float64_replacement();
  void set_has_string_replacement();
  void set_has_bool_replacement();
  inline bool has_Replacement() const;
  inline void clear_has_Replacement();
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<0, 6,
                                   0, 45,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const FillNaOp& from_msg);
    union ReplacementUnion {
      constexpr ReplacementUnion() : _constinit_{} {}
      ::google::protobuf::internal::ConstantInitialized _constinit_;
      ::int32_t int32_replacement_;
      ::int64_t int64_replacement_;
      float float32_replacement_;
      double float64_replacement_;
      ::google::protobuf::internal::ArenaStringPtr string_replacement_;
      bool bool_replacement_;
    } Replacement_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::uint32_t _oneof_case_[1];
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_NA_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull FillNaOp_class_data_;

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// IsNaOp

// -------------------------------------------------------------------

// FillNaOp

// int32 int32_replacement = 1;
inline bool FillNaOp::has_int32_replacement() const {
  return Replacement_case() == kInt32Replacement;
}
inline void FillNaOp::set_has_int32_replacement() {
  _impl_._oneof_case_[0] = kInt32Replacement;
}
inline void FillNaOp::clear_int32_replacement() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (Replacement_case() == kInt32Replacement) {
    _impl_.Replacement_.int32_replacement_ = 0;
    clear_has_Replacement();
  }
}
inline ::int32_t FillNaOp::int32_replacement() const {
  // @@protoc_insertion_point(field_get:mojo.spec.FillNaOp.int32_replacement)
  return _internal_int32_replacement();
}
inline void FillNaOp::set_int32_replacement(::int32_t value) {
  if (Replacement_case() != kInt32Replacement) {
    clear_Replacement();
    set_has_int32_replacement();
  }
  _impl_.Replacement_.int32_replacement_ = value;
  // @@protoc_insertion_point(field_set:mojo.spec.FillNaOp.int32_replacement)
}
inline ::int32_t FillNaOp::_internal_int32_replacement() const {
  if (Replacement_case() == kInt32Replacement) {
    return _impl_.Replacement_.int32_replacement_;
  }
  return 0;
}

// int64 int64_replacement = 2;
inline bool FillNaOp::has_int64_replacement() const {
  return Replacement_case() == kInt64Replacement;
}
inline void FillNaOp::set_has_int64_replacement() {
  _impl_._oneof_case_[0] = kInt64Replacement;
}
inline void FillNaOp::clear_int64_replacement() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (Replacement_case() == kInt64Replacement) {
    _impl_.Replacement_.int64_replacement_ = ::int64_t{0};
    clear_has_Replacement();
  }
}
inline ::int64_t FillNaOp::int64_replacement() const {
  // @@protoc_insertion_point(field_get:mojo.spec.FillNaOp.int64_replacement)
  return _internal_int64_replacement();
}
inline void FillNaOp::set_int64_replacement(::int64_t value) {
  if (Replacement_case() != kInt64Replacement) {
    clear_Replacement();
    set_has_int64_replacement();
  }
  _impl_.Replacement_.int64_replacement_ = value;
  // @@protoc_insertion_point(field_set:mojo.spec.FillNaOp.int64_replacement)
}
inline ::int64_t FillNaOp::_internal_int64_replacement() const {
  if (Replacement_case() == kInt64Replacement) {
    return _impl_.Replacement_.int64_replacement_;
  }
  return ::int64_t{0};
}

// float float32_replacement = 3;
inline bool FillNaOp::has_float32_replacement() const {
  return Replacement_case() == kFloat32Replacement;
}
inline void FillNaOp::set_has_float32_replacement() {
  _impl_._oneof_case_[0] = kFloat32Replacement;
}
inline void FillNaOp::clear_float32_replacement() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (Replacement_case() == kFloat32Replacement) {
    _impl_.Replacement_.float32_replacement_ = 0;
    clear_has_Replacement();
  }
}
inline float FillNaOp::float32_replacement() const {
  // @@protoc_insertion_point(field_get:mojo.spec.FillNaOp.float32_replacement)
  return _internal_float32_replacement();
}
inline void FillNaOp::set_float32_replacement(float value) {
  if (Replacement_case() != kFloat32Replacement) {
    clear_Replacement();
    set_has_float32_replacement();
  }
  _impl_.Replacement_.float32_replacement_ = value;
  // @@protoc_insertion_point(field_set:mojo.spec.FillNaOp.float32_replacement)
}
inline float FillNaOp::_internal_float32_replacement() const {
  if (Replacement_case() == kFloat32Replacement) {
    return _impl_.Replacement_.float32_replacement_;
  }
  return 0;
}

// double float64_replacement = 4;
inline bool FillNaOp::has_float64_replacement() const {
  return Replacement_case() == kFloat64Replacement;
}
inline void FillNaOp::set_has_float64_replacement() {
  _impl_._oneof_case_[0] = kFloat64Replacement;
}
inline void FillNaOp::clear_float64_replacement() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (Replacement_case() == kFloat64Replacement) {
    _impl_.Replacement_.float64_replacement_ = 0;
    clear_has_Replacement();
  }
}
inline double FillNaOp::float64_replacement() const {
  // @@protoc_insertion_point(field_get:mojo.spec.FillNaOp.float64_replacement)
  return _internal_float64_replacement();
}
inline void FillNaOp::set_float64_replacement(double value) {
  if (Replacement_case() != kFloat64Replacement) {
    clear_Replacement();
    set_has_float64_replacement();
  }
  _impl_.Replacement_.float64_replacement_ = value;
  // @@protoc_insertion_point(field_set:mojo.spec.FillNaOp.float64_replacement)
}
inline double FillNaOp::_internal_float64_replacement() const {
  if (Replacement_case() == kFloat64Replacement) {
    return _impl_.Replacement_.float64_replacement_;
  }
  return 0;
}

// string string_replacement = 5;
inline bool FillNaOp::has_string_replacement() const {
  return Replacement_case() == kStringReplacement;
}
inline void FillNaOp::set_has_string_replacement() {
  _impl_._oneof_case_[0] = kStringReplacement;
}
inline void FillNaOp::clear_string_replacement() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (Replacement_case() == kStringReplacement) {
    _impl_.Replacement_.string_replacement_.Destroy();
    clear_has_Replacement();
  }
}
inline const ::std::string& FillNaOp::string_replacement() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.FillNaOp.string_replacement)
  return _internal_string_replacement();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void FillNaOp::set_string_replacement(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (Replacement_case() != kStringReplacement) {
    clear_Replacement();

    set_has_string_replacement();
    _impl_.Replacement_.string_replacement_.InitDefault();
  }
  _impl_.Replacement_.string_replacement_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:mojo.spec.FillNaOp.string_replacement)
}
inline ::std::string* PROTOBUF_NONNULL FillNaOp::mutable_string_replacement()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  if (Replacement_case() != kStringReplacement) {
    clear_Replacement();

    set_has_string_replacement();
    _impl_.Replacement_.string_replacement_.InitDefault();
  }
  ::std::string* _s = _internal_mutable_string_replacement();
  // @@protoc_insertion_point(field_mutable:mojo.spec.FillNaOp.string_replacement)
  return _s;
}
inline const ::std::string& FillNaOp::_internal_string_replacement() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  if (Replacement_case() != kStringReplacement) {
    return ::google::protobuf::internal::GetEmptyStringAlreadyInited();
  }
  return _impl_.Replacement_.string_replacement_.Get();
}
inline void FillNaOp::_internal_set_string_replacement(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.Replacement_.string_replacement_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL FillNaOp::_internal_mutable_string_replacement() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.Replacement_.string_replacement_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE FillNaOp::release_string_replacement() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:mojo.spec.FillNaOp.string_replacement)
  if (Replacement_case() != kStringReplacement) {
    return nullptr;
  }
  clear_has_Replacement();
  return _impl_.Replacement_.string_replacement_.Release();
}
inline void FillNaOp::set_allocated_string_replacement(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (has_Replacement()) {
    clear_Replacement();
  }
  if (value != nullptr) {
    set_has_string_replacement();
    _impl_.Replacement_.string_replacement_.InitAllocated(value, GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:mojo.spec.FillNaOp.string_replacement)
}

// bool bool_replacement = 6;
inline bool FillNaOp::has_bool_replacement() const {
  return Replacement_case() == kBoolReplacement;
}
inline void FillNaOp::set_has_bool_replacement() {
  _impl_._oneof_case_[0] = kBoolReplacement;
}
inline void FillNaOp::clear_bool_replacement() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (Replacement_case() == kBoolReplacement) {
    _impl_.Replacement_.bool_replacement_ = false;
    clear_has_Replacement();
  }
}
inline bool FillNaOp::bool_replacement() const {
  // @@protoc_insertion_point(field_get:mojo.spec.FillNaOp.bool_replacement)
  return _internal_bool_replacement();
}
inline void FillNaOp::set_bool_replacement(bool value) {
  if (Replacement_case() != kBoolReplacement) {
    clear_Replacement();
    set_has_bool_replacement();
  }
  _impl_.Replacement_.bool_replacement_ = value;
  // @@protoc_insertion_point(field_set:mojo.spec.FillNaOp.bool_replacement)
}
inline bool FillNaOp::_internal_bool_replacement() const {
  if (Replacement_case() == kBoolReplacement) {
    return _impl_.Replacement_.bool_replacement_;
  }
  return false;
}

inline bool FillNaOp::has_Replacement() const {
  return Replacement_case() != REPLACEMENT_NOT_SET;
}
inline void FillNaOp::clear_has_Replacement() {
  _impl_._oneof_case_[0] = REPLACEMENT_NOT_SET;
}
inline FillNaOp::ReplacementCase FillNaOp::Replacement_case() const {
  return FillNaOp::ReplacementCase(_impl_._oneof_case_[0]);
}
// -------------------------------------------------------------------

// ImputeNaOp

// .mojo.spec.ImputeType type = 1;
inline void ImputeNaOp::clear_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.type_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
inline ::mojo::spec::ImputeType ImputeNaOp::type() const {
  // @@protoc_insertion_point(field_get:mojo.spec.ImputeNaOp.type)
  return _internal_type();
}
inline void ImputeNaOp::set_type(::mojo::spec::ImputeType value) {
  _internal_set_type(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_set:mojo.spec.ImputeNaOp.type)
}
inline ::mojo::spec::ImputeType ImputeNaOp::_internal_type() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return static_cast<::mojo::spec::ImputeType>(_impl_.type_);
}
inline void ImputeNaOp::_internal_set_type(::mojo::spec::ImputeType value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.type_ = value;
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace spec
}  // namespace mojo


namespace google {
namespace protobuf {

template <>
struct is_proto_enum<::mojo::spec::ImputeType> : std::true_type {};
template <>
inline const EnumDescriptor* PROTOBUF_NONNULL GetEnumDescriptor<::mojo::spec::ImputeType>() {
  return ::mojo::spec::ImputeType_descriptor();
}

}  // namespace protobuf
}  // namespace google

// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"

#endif  // NA_2eproto_2epb_2eh
