// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: Agg.proto
// Protobuf C++ Version: 6.33.5

#ifndef Agg_2eproto_2epb_2eh
#define Agg_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 6033005
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/message.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/generated_enum_reflection.h"
#include "google/protobuf/unknown_field_set.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_Agg_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_Agg_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_Agg_2eproto;
}  // extern "C"
namespace mojo {
namespace spec {
enum AggOpType : int;
extern const uint32_t AggOpType_internal_data_[];
class AggOp;
struct AggOpDefaultTypeInternal;
extern AggOpDefaultTypeInternal _AggOp_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull AggOp_class_data_;
}  // namespace spec
}  // namespace mojo
namespace google {
namespace protobuf {
template <>
internal::EnumTraitsT<::mojo::spec::AggOpType_internal_data_>
    internal::EnumTraitsImpl::value<::mojo::spec::AggOpType>;
}  // namespace protobuf
}  // namespace google

namespace mojo {
namespace spec {
enum AggOpType : int {
  UNKNOWN_AGG_OP_TYPE = 0,
  SUM = 1,
  PROD = 2,
  MIN = 3,
  MAX = 4,
  AggOpType_INT_MIN_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::min(),
  AggOpType_INT_MAX_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::max(),
};

extern const uint32_t AggOpType_internal_data_[];
inline constexpr AggOpType AggOpType_MIN =
    static_cast<AggOpType>(0);
inline constexpr AggOpType AggOpType_MAX =
    static_cast<AggOpType>(4);
inline bool AggOpType_IsValid(int value) {
  return 0 <= value && value <= 4;
}
inline constexpr int AggOpType_ARRAYSIZE = 4 + 1;
const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL AggOpType_descriptor();
template <typename T>
const ::std::string& AggOpType_Name(T value) {
  static_assert(::std::is_same<T, AggOpType>::value ||
                    ::std::is_integral<T>::value,
                "Incorrect type passed to AggOpType_Name().");
  return AggOpType_Name(static_cast<AggOpType>(value));
}
template <>
inline const ::std::string& AggOpType_Name(AggOpType value) {
  return ::google::protobuf::internal::NameOfDenseEnum<AggOpType_descriptor, 0, 4>(
      static_cast<int>(value));
}
inline bool AggOpType_Parse(
    ::absl::string_view name, AggOpType* PROTOBUF_NONNULL value) {
  return ::google::protobuf::internal::ParseNamedEnum<AggOpType>(AggOpType_descriptor(), name,
                                           value);
}

// ===================================================================


// -------------------------------------------------------------------

class AggOp final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:mojo.spec.AggOp) */ {
 public:
  inline AggOp() : AggOp(nullptr) {}
  ~AggOp() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(AggOp* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(AggOp));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR AggOp(::google::protobuf::internal::ConstantInitialized);

  inline AggOp(const AggOp& from) : AggOp(nullptr, from) {}
  inline AggOp(AggOp&& from) noexcept
      : AggOp(nullptr, ::std::move(from)) {}
  inline AggOp& operator=(const AggOp& from) {
    CopyFrom(from);
    return *this;
  }
  inline AggOp& operator=(AggOp&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const AggOp& default_instance() {
    return *reinterpret_cast<const AggOp*>(
        &_AggOp_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(AggOp& a, AggOp& b) { a.Swap(&b); }
  inline void Swap(AggOp* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(AggOp* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  AggOp* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<AggOp>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const AggOp& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const AggOp& from) { AggOp::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(AggOp* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.AggOp"; }

  explicit AggOp(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  AggOp(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const AggOp& from);
  AggOp(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, AggOp&& from) noexcept
      : AggOp(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kTypeFieldNumber = 1,
  };
  // .mojo.spec.AggOpType type = 1;
  void clear_type() ;
  ::mojo::spec::AggOpType type() const;
  void set_type(::mojo::spec::AggOpType value);

  private:
  ::mojo::spec::AggOpType _internal_type() const;
  void _internal_set_type(::mojo::spec::AggOpType value);

  public:
  // @@protoc_insertion_point(class_scope:mojo.spec.AggOp)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<0, 1,
                                   0, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const AggOp& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    int type_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_Agg_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull AggOp_class_data_;

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// AggOp

// .mojo.spec.AggOpType type = 1;
inline void AggOp::clear_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.type_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
inline ::mojo::spec::AggOpType AggOp::type() const {
  // @@protoc_insertion_point(field_get:mojo.spec.AggOp.type)
  return _internal_type();
}
inline void AggOp::set_type(::mojo::spec::AggOpType value) {
  _internal_set_type(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_set:mojo.spec.AggOp.type)
}
inline ::mojo::spec::AggOpType AggOp::_internal_type() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return static_cast<::mojo::spec::AggOpType>(_impl_.type_);
}
inline void AggOp::_internal_set_type(::mojo::spec::AggOpType value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.type_ = value;
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace spec
}  // namespace mojo


namespace google {
namespace protobuf {

template <>
struct is_proto_enum<::mojo::spec::AggOpType> : std::true_type {};
template <>
inline const EnumDescriptor* PROTOBUF_NONNULL GetEnumDescriptor<::mojo::spec::AggOpType>() {
  return ::mojo::spec::AggOpType_descriptor();
}

}  // namespace protobuf
}  // namespace google

// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"

#endif  // Agg_2eproto_2epb_2eh
